@@ -1,4 +1,4 @@
-GQD.estimates = function(x,thin = 100, burns, CI = c(0.05,0.95), corrmat = FALSE, acf.plot =TRUE)
+GQD.estimates = function(x,thin = 100, burns, CI = c(0.05,0.95), corrmat = FALSE, acf.plot =TRUE, palette = 'mono')
 {
   if(class(x)=='GQD.mle')
   {
@@ -23,10 +23,12 @@ GQD.estimates = function(x,thin = 100, burns, CI = c(0.05,0.95), corrmat = FALSE
     CI=t(apply(x$par.matrix[windw,], 2, quantile,probs = CI))
     form = function(x,mm = 2){format(round(x, mm), nsmall = mm)}
     dat=data.frame(cbind(form(cbind(est,CI),3)))
+    dat = matrix(as.numeric(as.matrix(dat)),dim(dat)[1])
     rownames(dat)=paste0('theta[',1:dim(x$par.matrix)[2],']')
     colnames(dat) = c('Estimate','Lower_CI','Upper_CI')
     
     dat2=data.frame(form(cor(x$par.matrix[windw,])))
+    dat2 = matrix(as.numeric(as.matrix(dat2)),dim(dat2)[1])
     rownames(dat2)=paste0('theta[',1:dim(x$par.matrix)[2],']')
     colnames(dat2)=paste0('theta[',1:dim(x$par.matrix)[2],']')
     if(acf.plot)
@@ -50,7 +52,12 @@ GQD.estimates = function(x,thin = 100, burns, CI = c(0.05,0.95), corrmat = FALSE
         d2=d2[row(test)[wh[1]]]
         par(mfrow=c(d1,d2))
       }
-      cols=rainbow_hcl(nper, start = 10, end = 275,c=100,l=70)
+      if(palette=='mono')
+      {
+        cols =rep('#222299',nper)
+      }else{
+        cols=rainbow_hcl(nper, start = 10, end = 275,c=100,l=70)
+      }
       for(i in 1:dim(x$par.matrix)[2])
       {
         acf(x$par.matrix[windw,i],main=paste0('ACF: theta[',i,']\nThin=',thin,', Burns=',burns,', N=',length(windw)),col = cols[i],lwd=2)
