@@ -1,6 +1,6 @@
 globalVariables('priors')
 GQD.mcmc <-
-function(X,time,mesh=10,theta,sds,updates,burns=min(round(updates/2),25000),Dtype='Saddle',Trunc=c(4,4),RK.order=4,P=200,alpha=0,lower=min(na.omit(X))/2,upper=max(na.omit(X))*2,exclude=NULL,plot.chain=TRUE,Tag=NA,wrt=FALSE,print.output=TRUE)
+function(X,time,mesh=10,theta,sds,updates,burns=min(round(updates/2),25000),Dtype='Saddle',Trunc=c(4,4),RK.order=4,P=200,alpha=0,lower=min(na.omit(X))/2,upper=max(na.omit(X))*2,exclude=NULL,plot.chain=TRUE,Tag=NA,wrt=FALSE,print.output=TRUE,palette='mono')
 {
   solver   =function(Xs, Xt, theta, N , delt , N2, tt  , P , alpha, lower , upper, tro  ){}
   rm(list =c('solver'))
@@ -1584,13 +1584,14 @@ if(Dindex!=1)
         par.matrix[,i]=theta
         ll[i]=lold
         kk=kk+is.true
-        acc[i]=kk/i
+        acc[i]=is.true
         if(max.retries>2000){print('Fail: Failed evaluation limit exceeded!');failed.chain=T;break;}
         if(any(is.na(theta))){print('Fail: Samples were NA! ');failed.chain=T;break;}
         setTxtProgressBar(pb, i)
         i = i+1
     }
     close(pb)
+    acc = cumsum(acc)/(1:updates)
     }
     if(adapt!=0)
     {
@@ -1692,7 +1693,12 @@ if(Dindex!=1)
         d2=d2[row(test)[wh[1]]]
         par(mfrow=c(d1,d2))
       }
-      cols=rainbow_hcl(nper, start = 10, end = 275,c=100,l=70)
+      if(palette=='mono')
+      {
+        cols =rep('#222299',nper)
+      }else{
+        cols=rainbow_hcl(nper, start = 10, end = 275,c=100,l=70)
+      }
       ylabs=paste0('theta[',1:nper,']')
       for(i in 1:nper)
       {
